//
//  PlayerViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/10/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit
import AVFoundation

class PlayerViewController: UIViewController, AVAudioPlayerDelegate {
    @IBOutlet var trackTitle: UILabel!
    @IBOutlet var playedTime: UILabel!
    var selectedAudioFileName = String()
    var fileURL = NSURL()
    var timer:NSTimer!
    var audioPlayer = AVAudioPlayer()

    override func viewDidLoad() {
        super.viewDidLoad()
        
        trackTitle.text = selectedAudioFileName
        let fileManager = NSFileManager.defaultManager()
        let urls = fileManager.URLsForDirectory(.DocumentDirectory, inDomains: .UserDomainMask)
        let documentsDirectoryURL: NSURL = urls.first!
        fileURL = documentsDirectoryURL.URLByAppendingPathComponent(selectedAudioFileName)
        
        do {
            audioPlayer = try AVAudioPlayer(contentsOfURL: fileURL)
            audioPlayer.prepareToPlay()
            audioPlayer.delegate = self
            
            /*** DEBUG STATEMENT ***/
            print("The audioPlayer is initialized with this URL:\n\(fileURL)")
            
        } catch let error as NSError {
            print("AUDIO PLAYER ERROR\n\(error.localizedDescription)")
        }
    }

    override func viewWillDisappear(animated: Bool) {
        if audioPlayer.playing {
            audioPlayer.stop() // Stop the sound that's playing
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func playPauseButtonTapped(sender: AnyObject) {
        if audioPlayer.playing {
            audioPlayer.pause()
        } else {
            audioPlayer.play()
            timer = NSTimer.scheduledTimerWithTimeInterval(1.0, target: self, selector: "updatePlayedTime", userInfo: nil, repeats: true)
        }
    }
    
    @IBAction func stopButtonTapped(sender: AnyObject) {
        audioPlayer.currentTime = 0
        audioPlayer.stop()
    }
    
    func updatePlayedTime() {
        let currentTime = Int(audioPlayer.currentTime)
        let minutes = currentTime/60
        let seconds = currentTime - minutes * 60
        playedTime.text = NSString(format: "%02d:%02d", minutes, seconds) as String
    }
    
    func audioPlayerDidFinishPlaying(player: AVAudioPlayer, successfully flag: Bool) {
        let msg = "The audio file, \(selectedAudioFileName) finished playing"
        let alert = UIAlertController(title: "Audio Diary", message: msg, preferredStyle: .Alert)
        alert.addAction(UIAlertAction(title: "OK", style: .Default, handler: nil))
        self.presentViewController(alert, animated: true, completion: nil)
    }
    
    func audioPlayerDecodeErrorDidOccur(player: AVAudioPlayer, error: NSError?) {
        let alert = UIAlertController(title: "Audio Diary", message: "Decoding Error: \(error?.localizedDescription)", preferredStyle: .Alert)
        alert.addAction(UIAlertAction(title: "OK", style: .Default, handler: nil))
        self.presentViewController(alert, animated: true, completion: nil)
    }
}
