//
//  RecorderViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/4/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit
import AVFoundation

class RecorderViewController: UIViewController, AVAudioRecorderDelegate {
    @IBOutlet weak var progressView: UIProgressView!
    var progressCounter: Float = 0.00
    var progressViewTimer: NSTimer!
    var soundFileName: String!
    var recordingSession: AVAudioSession!
    var audioRecorder: AVAudioRecorder!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.view.backgroundColor = UIColor(patternImage: UIImage(named:"wallpaper.png")!)
        progressView.tintColor = UIColor(red: 1.0, green: 0.02, blue: 0.00, alpha: 1.0)
        progressView.progress = progressCounter
        
        /*** DEBUG STATEMENT ***/
        let paths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        print(paths.first!)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    @IBAction func recordButtonClicked() {
        progressCounter = 0.0
        setupAudioRecorder()
        audioRecorder.record()
        
        if progressViewTimer != nil {
            progressViewTimer.invalidate()
        }
        
        progressViewTimer = NSTimer.scheduledTimerWithTimeInterval(0.1,
            target:self,
            selector:"updateProgressView",
            userInfo:nil,
            repeats:true)
    }
    
    @IBAction func stopButtonClicked() {
        if audioRecorder != nil {
            audioRecorder.stop()
            progressViewTimer.invalidate()
            progressView.progress = 0.0
        }
    }
    
    func updateProgressView() {
        progressCounter += 0.01
        progressView.progress = progressCounter
        
        if progressCounter > 1.0 {
            progressViewTimer.invalidate()
        }
        
        /*** DEBUG STATEMENT ***/
        print("Progress: \(progressCounter)")
    }
    
    func setupAudioRecorder() {
        recordingSession = AVAudioSession.sharedInstance()
        
        do {
            try recordingSession.setCategory(AVAudioSessionCategoryPlayAndRecord)
            try recordingSession.setActive(true)
            
            let fileManager = NSFileManager.defaultManager()
            let urls = fileManager.URLsForDirectory(.DocumentDirectory, inDomains: .UserDomainMask)
            let documentsDirectoryURL: NSURL = urls.first!
            soundFileName = "recording-" + randomString() + ".caf"
            let audioFileURL = documentsDirectoryURL.URLByAppendingPathComponent(self.soundFileName)
            
            /*** DEBUG STATEMENT ***/
            print("Audio File Url\n\(audioFileURL)")
            
            let audioSettings = [AVFormatIDKey: Int(kAudioFormatMPEG4AAC),
                AVSampleRateKey: 12000.0,
                AVNumberOfChannelsKey: 1 as NSNumber,
                AVEncoderAudioQualityKey: AVAudioQuality.High.rawValue]
            
            do {
                audioRecorder = try AVAudioRecorder(URL: audioFileURL, settings: audioSettings)
                audioRecorder.delegate = self
                audioRecorder.prepareToRecord()
            } catch let error as NSError {
                // Recorder not initialized
                /*** DEBUG STATEMENT ***/
                print(error.localizedDescription)
            }
        } catch let error as NSError {
            print("Recording session failed: \(error.localizedDescription)")
        }
    }
    
    func randomString() -> String {
        let len: Int = 3 // String length
        let needle : NSString = "0123456789"
        let randomString : NSMutableString = NSMutableString(capacity: len)
        
        for (var i=0; i < len; i++){
            let length = UInt32 (needle.length)
            let rand = arc4random_uniform(length)
            randomString.appendFormat("%C", needle.characterAtIndex(Int(rand)))
        }
        
        return randomString as String
    }
    
    // MARK: - AVAudioRecorder delegates
    
    func audioRecorderDidFinishRecording(recorder: AVAudioRecorder, successfully flag: Bool) {
        let msg = "Your recording was saved as, \(soundFileName)"
        let alert = UIAlertController(title: "Audio Diary", message: msg, preferredStyle: .Alert)
        alert.addAction(UIAlertAction(title: "OK", style: .Default, handler: nil))
        self.presentViewController(alert, animated: true, completion: nil)
    }
    
    func audioRecorderEncodeErrorDidOccur(recorder: AVAudioRecorder, error: NSError?) {
        let alert = UIAlertController(title: "Audio Diary", message: error!.localizedDescription, preferredStyle: .Alert)
        alert.addAction(UIAlertAction(title: "OK", style: .Default, handler: nil))
        self.presentViewController(alert, animated: true, completion: nil)
    }
}



