//
//  RecordingsViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/4/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit

class RecordingsViewController: UITableViewController {
    var tableDataSource = [String]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = UIColor(patternImage: UIImage(named:"wallpaper.jpg")!)
        tableView.tableFooterView = UIView(frame:CGRectZero)
        tableView.separatorColor = UIColor.clearColor()
        fetchSoundFiles()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    // MARK: - Table view data source functions (5)
    
    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        // Return the number of sections.
        return 1
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // Return the number of rows in the section.
        return tableDataSource.count
    }
    
    // This function configure and display content in the table view cells
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        // Create a reusable cell
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath) as UITableViewCell
        
        // Configure the table cell
        cell.backgroundColor = UIColor(red:1.00, green:0.80, blue:0.60, alpha:1.00)
        cell.imageView!.image = UIImage(named:"audio-file")
        cell.textLabel!.text = tableDataSource[indexPath.row]
        cell.backgroundColor = UIColor.clearColor()
        
        // Return the configured cell
        return cell
    }
    
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            let soundFileToDelete = self.tableDataSource[indexPath.row]
            self.deleteAudioFile(soundFileToDelete)
            tableDataSource.removeAtIndex(indexPath.row)
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
            tableView.reloadData()
        }
    }
    
    // MARK: - Data model functions (3)
    
    func fetchSoundFiles() { // Get the full path to the Documents directory
        let paths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        let docsDir = paths.first!
        
        do {
            // Get all files that are in the Documents folder
            let directoryItems: Array = try NSFileManager.defaultManager().contentsOfDirectoryAtPath(docsDir)
            for item in directoryItems as [String] {
                // Filter content of the directoryItem array and...
                if item.hasSuffix("caf") {
                    //add only sound files in the tableView's dataSource array
                    tableDataSource.append(item)
                }
            }
        } catch let error as NSError {
            print("Read Documents directory failed for this reason:\n\(error.localizedDescription)")
        }
    }

    func deleteAudioFile(soundFileToDelete: String) {
        let paths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        let documentsDirectoryPath = paths.first!
        let sourceFile = documentsDirectoryPath.stringByAppendingString("/"+soundFileToDelete)
        let fileManager = NSFileManager.defaultManager()
        
        do {
            try fileManager.removeItemAtPath(sourceFile)
        } catch let error as NSError {
            print("Failed to delete the sound file:\n\(error.localizedDescription)")
        }
    }
    
    // MARK: - Navigation
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        let controller = segue.destinationViewController as! PlayerViewController
        
        if segue.identifier == "showPlayer" {
            let indexPath = self.tableView.indexPathForSelectedRow
            controller.selectedAudioFileName = tableDataSource[indexPath!.row]
        }
    }
}
